@@ -1,4 +1,6 @@
-use openlineage_sql::{get_dialect, get_generic_dialect, parse_sql, parse_multiple_statements, DbTableMeta, SqlMeta};
+use openlineage_sql::{
+    get_dialect, get_generic_dialect, parse_multiple_statements, parse_sql, DbTableMeta, SqlMeta,
+};
 use sqlparser::dialect::PostgreSqlDialect;
 
 pub fn test_sql(sql: &str) -> SqlMeta {
@@ -19,7 +21,6 @@ pub fn test_multiple_sql_dialect(sqls: Vec<&str>, dialect: &str) -> SqlMeta {
     }
 }
 
-
 pub fn test_sql_dialect(sql: &str, dialect: &str) -> SqlMeta {
     match parse_sql(sql, get_dialect(dialect), None) {
         Ok(meta) => meta,
